﻿using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Configuration;
using DAL;
using DAS;
using BLL.Recuperacion_DGA;
using BLL.Integracion_DGA;
using Shared.Utils;
using Shared.Utils.Variables_Entorno;

namespace Integracion_DGA
{
    class Program
    {
        static async Task Main(string[] args)
        {
            var nexusApiUrl = EnviromentUtils.GetEnvNexusApiUrl("NEXUS_API_URL");
            var subterraneaApiUrl = EnviromentUtils.GetEnvSubterraneaApiUrl("SUBTERRANEAS_API_URL");
            var bdConexion = EnviromentUtils.GetEnvBDConexion("CONEXION_BD_ENVIO_DGA");
            var credencialesDGA = EnviromentUtils.GetEnvCredencialesDGA("DGA_CREDENCIALES");

            using IHost host = Host.CreateDefaultBuilder(args)
                .ConfigureServices((context, services) =>
                {
                    IConfiguration configuration = context.Configuration;
                    services.AddSingleton<IConfiguration>(configuration);
                    services.AddSingleton(nexusApiUrl);
                    services.AddSingleton(subterraneaApiUrl);
                    services.AddSingleton(bdConexion);
                    services.AddSingleton(credencialesDGA);

                    services.AddScoped<MedicionScadaRepository>();
                    services.AddScoped<EnvioDGA>();
                    services.AddHttpClient<RegistrarMedicion>();
                    //Estos dos servicios son los que migre del otro proyecto
                    services.AddScoped<JobsDgaRepository>();
                    services.AddScoped<JobsDgaVilosRepository>();
                    services.AddScoped<JobsDgaSupFlujRepository>();
                    services.AddScoped<LogMedicionScadaRepository>();
                    services.AddScoped<ApiService>();
                    services.AddScoped<BusinessLogic>();
                })
                .Build();
            
            var envioDGA = host.Services.GetRequiredService<EnvioDGA>();
            var bussinessLogic = host.Services.GetRequiredService<BusinessLogic>();
            var apiService = host.Services.GetRequiredService<ApiService>();
            //await bussinessLogic.Run();
            //var mediciones = await envioDGA.ObtenerMedicionesAsync();
        }
    }
}
